/*
 * tsc.h -- header to deal with the TSC register timestamps.
 * 
 * Written by Stanislav Shalunov, http://www.internet2.edu/~shalunov/
 * 
 * Copyright 2005, Internet2.
 * Legal conditions are in file LICENSE
 * (MD5 = ecfa50d1b0bfbb81b658c810d0476a52).
 */

#ifndef THRULAY_TSC_H_INCLUDED
#define THRULAY_TSC_H_INCLUDED

#include <sys/cdefs.h>

void
init_tsc(void);

u_int64_t
get_tps(void);

void
tsc2ntp(u_int64_t, char *);

u_int64_t
ntp2tsc(const char *);

/* 
 * Return the current value of the TSC register.
 *
 * XXX: This should work on i386-based machines with a TSC register.
 * Ports to other architectures would require extra code.  Such OSes
 * as Linux and FreeBSD provide ways to read the TSC register with
 * get_cycles() and rdtsc() functions (with different include files),
 * but since the interface is different on Linux and FreeBSD, both of
 * which I would like to support, some ifdefs would be required
 * anyway, even to support a single (i386) architecture.
 */
static __inline u_int64_t
read_tsc(void)
{
	u_int64_t r;

	__asm __volatile("rdtsc": "=A" (r));
	return r;
}

#endif /* ifndef THRULAY_TSC_H_INCLUDED */
